pm4py.algo.conformance.alignments.decomposed.variants package
=============================================================

Submodules
----------

pm4py.algo.conformance.alignments.decomposed.variants.recompos\_maximal module
------------------------------------------------------------------------------

.. automodule:: pm4py.algo.conformance.alignments.decomposed.variants.recompos_maximal
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.conformance.alignments.decomposed.variants
   :members:
   :undoc-members:
   :show-inheritance:
